***********************************************
* "Do Better Paid Politicians Perform Better?"
* Figure 2
***********************************************


use SIN19932001.dta, clear
keep if gender!=. & age!=. & years_school!=. & empl_not!=. & empl_boss!=. & empl_low!=. & empl_entr!=.

foreach i in 100 {
gen pop_census_grp`i' = `i'*int((pop_census)/`i')
egen  mean_pop_census`i' = mean(pop_census), by(pop_census_grp`i')
foreach var of varlist gender age years_school empl_not empl_entr empl_boss empl_low {
  egen `var'_mean`i' = mean(`var'), by(pop_census_grp`i')
}
}

gen pop_census2=pop_census^2
gen pop_census3=pop_census^3

sum id_city if pop_census>=4950 & pop_census<5000
sum id_city if pop_census>=5000 & pop_census<=5050
sum id_city if pop_census>=4900 & pop_census<5000
sum id_city if pop_census>=5000 & pop_census<=5100

reg gender pop_census if pop_census>=3300 & pop_census<5000
predict yhat_left if pop_census>=3300 & pop_census<5000
predict SE_left if pop_census>=3300 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg gender pop_census if pop_census>=5000 & pop_census<=6700
predict yhat_right if pop_census>=5000 & pop_census<=6700
predict SE_right if pop_census>=5000 & pop_census<=6700, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=3300 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6700, pstyle(p p3 p3) sort) /*
*/     (lowess gender pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess gender pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter gender_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(medlarge)) ytitle(Female, size(medlarge)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(0 .05 .1 .15 .2)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save mayor_gender.gph, replace

reg age pop_census if pop_census>=3300 & pop_census<5000
predict yhat_left if pop_census>=3300 & pop_census<5000
predict SE_left if pop_census>=3300 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg age pop_census if pop_census>=5000 & pop_census<=6700
predict yhat_right if pop_census>=5000 & pop_census<=6700
predict SE_right if pop_census>=5000 & pop_census<=6700, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=3300 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6700, pstyle(p p3 p3) sort) /*
*/     (lowess age pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess age pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter age_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(medlarge)) ytitle(Age, size(medlarge)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(42 44 46 48 50)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save mayor_age.gph, replace

reg years_school pop_census if pop_census>3900 & pop_census<5000
predict yhat_left if pop_census>=3900 & pop_census<5000
predict SE_left if pop_census>=3900 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg years_school pop_census if pop_census>=5000 & pop_census<=6100
predict yhat_right if pop_census>=5000 & pop_census<=6100
predict SE_right if pop_census>=5000 & pop_census<=6100, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=3900 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6100, pstyle(p p3 p3) sort) /*
*/     (lowess years_school pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess years_school pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter years_school_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(medlarge)) ytitle(Years school, size(medlarge)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(13 14 15 16)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save mayor_years_school.gph, replace

reg empl_not pop_census if pop_census>=4000 & pop_census<5000
predict yhat_left if pop_census>=4000 & pop_census<5000
predict SE_left if pop_census>=4000 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg empl_not pop_census if pop_census>=5000 & pop_census<=6000
predict yhat_right if pop_census>=5000 & pop_census<=6000
predict SE_right if pop_census>=5000 & pop_census<=6000, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=4000 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6000, pstyle(p p3 p3) sort) /*
*/     (lowess empl_not pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess empl_not pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter empl_not_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(medlarge)) ytitle(Not employed, size(medlarge)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(0 .05 .1 .15 .2)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save mayor_empl_not.gph, replace

reg empl_entr pop_census if pop_census>=3600 & pop_census<5000
predict yhat_left if pop_census>=3600 & pop_census<5000
predict SE_left if pop_census>=3600 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg empl_entr pop_census if pop_census>=5000 & pop_census<=6400
predict yhat_right if pop_census>=5000 & pop_census<=6400
predict SE_right if pop_census>=5000 & pop_census<=6400, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=3600 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6400, pstyle(p p3 p3) sort) /*
*/     (lowess empl_entr pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess empl_entr pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter empl_entr_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(medlarge)) ytitle(Entrepreneur, size(medlarge)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(.1 .2 .3 .4 .5)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save mayor_empl_entr.gph, replace

reg empl_boss pop_census if pop_census>=3300 & pop_census<5000
predict yhat_left if pop_census>=3300 & pop_census<5000
predict SE_left if pop_census>=3300 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg empl_boss pop_census if pop_census>=5000 & pop_census<=6700
predict yhat_right if pop_census>=5000 & pop_census<=6700
predict SE_right if pop_census>=5000 & pop_census<=6700, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=3300 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6700, pstyle(p p3 p3) sort) /*
*/     (lowess empl_boss pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess empl_boss pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter empl_boss_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(medlarge)) ytitle(White collar, size(medlarge)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(.2 .3 .4 .5 .6)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save mayor_empl_boss.gph, replace

reg empl_low pop_census if pop_census>=3600 & pop_census<5000
predict yhat_left if pop_census>=3600 & pop_census<5000
predict SE_left if pop_census>=3600 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg empl_low pop_census if pop_census>=5000 & pop_census<=6400
predict yhat_right if pop_census>=5000 & pop_census<=6400
predict SE_right if pop_census>=5000 & pop_census<=6400, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=3600 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6400, pstyle(p p3 p3) sort) /*
*/     (lowess empl_low pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess empl_low pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter empl_low_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(medlarge)) ytitle(Blue collar, size(medlarge)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(.05 .15 .25)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save mayor_empl_low.gph, replace

graph combine mayor_gender.gph mayor_age.gph mayor_years_school.gph mayor_empl_not.gph mayor_empl_entr.gph mayor_empl_boss.gph mayor_empl_low.gph
graph save graphmayor.gph, replace
graph export graphmayor.png, replace
graph export graphmayor.eps, replace
