***********************************************
* "Do Better Paid Politicians Perform Better?"
* Figure 4
***********************************************


use SIN19932001.dta, clear
keep if year_termination-year_election>=4 & year_termination!=. & year_election!=.
keep if avg_deficit_pc!=. & avg_expend_pc!=. & avg_expend_cap_pc!=. & avg_expend_rigid_pc!=. & avg_expend_serv_pc!=. & avg_rev_pc!=. & avg_rev_transf_pc!=. & avg_rev_tax_pc!=. & avg_rev_notax_pc!=. & avg_rev_collect!=. & avg_expend_speed!=.

sort id_mayor year_election
foreach var in avg_deficit_pc avg_expend_pc avg_expend_cap_pc avg_expend_rigid_pc avg_expend_serv_pc avg_rev_pc avg_rev_transf_pc avg_rev_tax_pc avg_rev_notax_pc avg_rev_collect avg_expend_speed {
by id_mayor: gen shift_`var'=(`var'-`var'[_n-1]) if term_limit==1 
gen panel_`var'=.
by id_mayor: replace panel_`var'=1 if shift_`var'!=.
by id_mayor: replace panel_`var'=1 if shift_`var'[_n+1]!=.
}

g s=1-term_limit
gen t5000Xs=t5000*s
gen pop5000Xs=pop5000*s 
gen t5000_int1Xs=t5000_int1*s
gen pop5000_2Xs=pop5000_2*s 
gen t5000_int2Xs=t5000_int2*s
gen pop5000_3Xs=pop5000_3*s 
gen t5000_int3Xs=t5000_int3*s
gen pop5000_4Xs=pop5000_4*s 
gen t5000_int4Xs=t5000_int4*s

* create e(samples)
reg avg_deficit_pc avg_expend_pc avg_expend_cap_pc avg_expend_rigid_pc avg_expend_serv_pc avg_rev_pc avg_rev_transf_pc avg_rev_tax_pc avg_rev_notax_pc t5000 pop5000 t5000_int1 if pop_census>3250 & pop_census<6750 & term_limit==0 /*
*/ & panel_avg_deficit_pc==1 & panel_avg_expend_pc==1 & panel_avg_expend_cap_pc==1 & panel_avg_expend_rigid_pc==1 & panel_avg_expend_serv_pc==1 & panel_avg_rev_pc==1 & panel_avg_rev_transf_pc==1 & panel_avg_rev_tax_pc==1 & panel_avg_rev_notax_pc==1,cluster(id_city)
gen sample_overall_max=e(sample)==1
reg avg_deficit_pc avg_expend_pc avg_expend_cap_pc avg_expend_rigid_pc avg_expend_serv_pc avg_rev_pc avg_rev_transf_pc avg_rev_tax_pc avg_rev_notax_pc pop5000 t5000 t5000_int1 s pop5000Xs t5000Xs t5000_int1Xs if pop_census>3250 & pop_census<6750 /*
*/ & panel_avg_deficit_pc==1 & panel_avg_expend_pc==1 & panel_avg_expend_cap_pc==1 & panel_avg_expend_rigid_pc==1 & panel_avg_expend_serv_pc==1 & panel_avg_rev_pc==1 & panel_avg_rev_transf_pc==1 & panel_avg_rev_tax_pc==1 & panel_avg_rev_notax_pc==1,cluster(id_city)
gen sample_incentive_max=e(sample)==1

keep if term_limit==1
keep if sample_incentive_max==1

foreach i in 100 {
gen pop_census_grp`i' = `i'*int((pop_census)/`i')
egen  mean_pop_census`i' = mean(pop_census), by(pop_census_grp`i')
foreach var of varlist avg_deficit_pc avg_expend_pc avg_expend_cap_pc avg_expend_serv_pc avg_expend_rigid_pc avg_rev_pc avg_rev_transf_pc avg_rev_tax_pc avg_rev_notax_pc avg_rev_collect avg_expend_speed {
  egen `var'_mean`i' = mean(`var') if panel_`var'==1, by(pop_census_grp`i')
}
}

reg avg_deficit_pc pop_census if pop_census>=3700 & pop_census<5000
predict yhat_left if pop_census>=3700 & pop_census<5000
predict SE_left if pop_census>=3700 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg avg_deficit_pc pop_census if pop_census>=5000 & pop_census<=6300
predict yhat_right if pop_census>=5000 & pop_census<=6300
predict SE_right if pop_census>=5000 & pop_census<=6300, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=3700 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6300, pstyle(p p3 p3) sort) /*
*/     (lowess avg_deficit_pc pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess avg_deficit_pc pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter avg_deficit_pc_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(large)) ytitle(Deficit pc, size(large)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(-10 0 10 20 30 40)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save budget_avg_deficit_pc_TL.gph, replace

reg avg_expend_pc pop_census if pop_census>=4000 & pop_census<5000
predict yhat_left if pop_census>=4000 & pop_census<5000
predict SE_left if pop_census>=4000 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg avg_expend_pc pop_census if pop_census>=5000 & pop_census<=6000
predict yhat_right if pop_census>=5000 & pop_census<=6000
predict SE_right if pop_census>=5000 & pop_census<=6000, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
drop if avg_expend_pc_mean>1600
twoway (line yhat_left pop_census if pop_census>=4000 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6000, pstyle(p p3 p3) sort) /*
*/     (lowess avg_expend_pc pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess avg_expend_pc pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter avg_expend_pc_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(large)) ytitle(Tot. exp. pc, size(large)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(800 1000 1200 1400)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save budget_avg_expend_pc_TL.gph, replace

reg avg_expend_cap_pc pop_census if pop_census>=3300 & pop_census<5000
predict yhat_left if pop_census>=3300 & pop_census<5000
predict SE_left if pop_census>=3300 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg avg_expend_cap_pc pop_census if pop_census>=5000 & pop_census<=6700
predict yhat_right if pop_census>=5000 & pop_census<=6700
predict SE_right if pop_census>=5000 & pop_census<=6700, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=3300 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6700, pstyle(p p3 p3) sort) /*
*/     (lowess avg_expend_cap_pc pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess avg_expend_cap_pc pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter avg_expend_cap_pc_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(large)) ytitle(Inv. pc, size(large)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(200 400 600 800)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save budget_avg_expend_cap_pc_TL.gph, replace

reg avg_expend_rigid_pc pop_census if pop_census>=3600 & pop_census<5000
predict yhat_left if pop_census>=3600 & pop_census<5000
predict SE_left if pop_census>=3600 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg avg_expend_rigid_pc pop_census if pop_census>=5000 & pop_census<=6400
predict yhat_right if pop_census>=5000 & pop_census<=6400
predict SE_right if pop_census>=5000 & pop_census<=6400, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=3600 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6400, pstyle(p p3 p3) sort) /*
*/     (lowess avg_expend_rigid_pc pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess avg_expend_rigid_pc pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter avg_expend_rigid_pc_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(large)) ytitle(Pers. & interests pc, size(large)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(200 300 400)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save budget_avg_expend_rigid_pc_TL.gph, replace

reg avg_expend_serv_pc pop_census if pop_census>=3500 & pop_census<5000
predict yhat_left if pop_census>=3500 & pop_census<5000
predict SE_left if pop_census>=3500 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg avg_expend_serv_pc pop_census if pop_census>=5000 & pop_census<=6500
predict yhat_right if pop_census>=5000 & pop_census<=6500
predict SE_right if pop_census>=5000 & pop_census<=6500, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=3500 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6500, pstyle(p p3 p3) sort) /*
*/     (lowess avg_expend_serv_pc pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess avg_expend_serv_pc pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter avg_expend_serv_pc_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(large)) ytitle(Serv. & goods pc, size(large)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(300 400 500)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save budget_avg_expend_serv_pc_TL.gph, replace

reg avg_rev_pc pop_census if pop_census>=4000 & pop_census<5000
predict yhat_left if pop_census>=4000 & pop_census<5000
predict SE_left if pop_census>=4000 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg avg_rev_pc pop_census if pop_census>=5000 & pop_census<=6000
predict yhat_right if pop_census>=5000 & pop_census<=6000
predict SE_right if pop_census>=5000 & pop_census<=6000, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
drop if avg_rev_pc_mean>1400
twoway (line yhat_left pop_census if pop_census>=4000 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6000, pstyle(p p3 p3) sort) /*
*/     (lowess avg_rev_pc pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess avg_rev_pc pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter avg_rev_pc_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(large)) ytitle(Tot. rev. pc, size(large)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(800 1000 1200 1400)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save budget_avg_rev_pc_TL.gph, replace

reg avg_rev_transf_pc pop_census if pop_census>=3600 & pop_census<5000
predict yhat_left if pop_census>=3600 & pop_census<5000
predict SE_left if pop_census>=3600 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg avg_rev_transf_pc pop_census if pop_census>=5000 & pop_census<=6400
predict yhat_right if pop_census>=5000 & pop_census<=6400
predict SE_right if pop_census>=5000 & pop_census<=6400, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
drop if avg_rev_transf_pc_mean>1000
twoway (line yhat_left pop_census if pop_census>=3600 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6400, pstyle(p p3 p3) sort) /*
*/     (lowess avg_rev_transf_pc pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess avg_rev_transf_pc pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter avg_rev_transf_pc_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(large)) ytitle(Transf. pc, size(large)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(400 600 800 1000)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save budget_avg_rev_transf_pc_TL.gph, replace

reg avg_rev_tax_pc pop_census if pop_census>=3300 & pop_census<5000
predict yhat_left if pop_census>=3300 & pop_census<5000
predict SE_left if pop_census>=3300 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg avg_rev_tax_pc pop_census if pop_census>=5000 & pop_census<=6700
predict yhat_right if pop_census>=5000 & pop_census<=6700
predict SE_right if pop_census>=5000 & pop_census<=6700, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=3300 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6700, pstyle(p p3 p3) sort) /*
*/     (lowess avg_rev_tax_pc pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess avg_rev_tax_pc pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter avg_rev_tax_pc_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(large)) ytitle(Tax pc, size(large)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(200 250 300 350 400)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save budget_avg_rev_tax_pc_TL.gph, replace

reg avg_rev_notax_pc pop_census if pop_census>=3900 & pop_census<5000
predict yhat_left if pop_census>=3900 & pop_census<5000
predict SE_left if pop_census>=3900 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg avg_rev_notax_pc pop_census if pop_census>=5000 & pop_census<=6100
predict yhat_right if pop_census>=5000 & pop_census<=6100
predict SE_right if pop_census>=5000 & pop_census<=6100, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=3900 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6100, pstyle(p p3 p3) sort) /*
*/     (lowess avg_rev_notax_pc pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess avg_rev_notax_pc pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter avg_rev_notax_pc_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(large)) ytitle(Tariff pc, size(large)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(0 100 200 300 400)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save budget_avg_rev_notax_pc_TL.gph, replace

reg avg_rev_collect pop_census if pop_census>=4100 & pop_census<5000
predict yhat_left if pop_census>=4100 & pop_census<5000
predict SE_left if pop_census>=4100 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg avg_rev_collect pop_census if pop_census>=5000 & pop_census<=5900
predict yhat_right if pop_census>=5000 & pop_census<=5900
predict SE_right if pop_census>=5000 & pop_census<=5900, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=4100 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=5900, pstyle(p p3 p3) sort) /*
*/     (lowess avg_rev_collect pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess avg_rev_collect pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter avg_rev_collect_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(large)) ytitle(Speed of collection, size(large)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(60 65 70 75)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save efficiency_avg_rev_collect_TL.gph, replace

reg avg_expend_speed pop_census if pop_census>=3500 & pop_census<5000
predict yhat_left if pop_census>=3500 & pop_census<5000
predict SE_left if pop_census>=3500 & pop_census<5000, stdp
gen low_left = yhat_left - 1.64*(SE_left)
gen high_left = yhat_left + 1.64*(SE_left)
reg avg_expend_speed pop_census if pop_census>=5000 & pop_census<=6500
predict yhat_right if pop_census>=5000 & pop_census<=6500
predict SE_right if pop_census>=5000 & pop_census<=6500, stdp
gen low_right = yhat_right - 1.64*(SE_right)
gen high_right = yhat_right + 1.64*(SE_right)
twoway (line yhat_left pop_census if pop_census>=3500 & pop_census<5000, pstyle(p p3 p3) sort) /*
*/     (line yhat_right pop_census if pop_census>=5000 & pop_census<=6500, pstyle(p p3 p3) sort) /*
*/     (lowess avg_expend_speed pop_census if pop_census<5000, mean lcolor(blue) lwidth(medthick) bwidth(1)) /*
*/     (lowess avg_expend_speed pop_census if pop_census>=5000, mean lcolor(red) lwidth(medthick) bwidth(1)) /*
*/     (scatter avg_expend_speed_mean mean_pop_census, msize(small) mlwidth(vthin) msymbol(circle_hollow) mcolor(gray)), /*
*/     xtitle(Population, size(large)) ytitle(Speed of payment, size(large)) legend(off) xline(5000, lwidth(0.2) lcolor(black)) xscale(range(3250 6750)) xlabel(4000 5000 6000) ylabel(75 80 85)
drop yhat_right SE_right high_right low_right yhat_left SE_left high_left low_left
graph save efficiency_avg_expend_speed_TL.gph, replace

graph combine budget_avg_deficit_pc_TL.gph budget_avg_expend_pc_TL.gph budget_avg_expend_cap_pc_TL.gph budget_avg_expend_rigid_pc_TL.gph budget_avg_expend_serv_pc_TL.gph budget_avg_rev_pc_TL.gph budget_avg_rev_transf_pc_TL.gph budget_avg_rev_tax_pc_TL.gph budget_avg_rev_notax_pc_TL.gph efficiency_avg_rev_collect_TL.gph efficiency_avg_expend_speed_TL.gph
graph save graphbudgetefficiencyTL.gph, replace
graph export graphbudgetefficiencyTL.png, replace
graph export graphbudgetefficiencyTL.eps, replace
